#
# spec file for package python-proton-vpn-api-core
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-proton-vpn-api-core
Version:        0.42.4
Release:        1.1
Summary:        Proton VPN API library
License:        GPL-3.0-or-later
Group:          Development/Languages/Python
URL:            https://github.com/ProtonVPN/python-proton-vpn-api-core
Source:         https://github.com/ProtonVPN/python-proton-vpn-api-core/archive/refs/tags/v%{version}.tar.gz
BuildRequires:  %{python_module PyNaCl}
BuildRequires:  %{python_module cryptography}
BuildRequires:  %{python_module distro}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module proton-core}
BuildRequires:  %{python_module pytest-asyncio}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest}
# sentry-sdk is not mandatory and only available in TW
%if 0%{?suse_version} > 1600
BuildRequires:  %{python_module sentry-sdk}
%endif
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
Requires:       python-PyNaCl
Requires:       python-cryptography
Requires:       python-distro
Requires:       python-proton-core >= 0.4.0
# sentry-sdk is not mandatory and only available in TW
%if 0%{?suse_version} > 1600
Requires:       python-sentry-sdk
%endif
Conflicts:      proton-vpn < 4.8.2
Conflicts:      python-proton-vpn-network-manager < 0.12.10
Obsoletes:      python-proton-vpn-session <= 0.6.7
Obsoletes:      python-proton-vpn-connection <= 0.14.4
Obsoletes:      python-proton-vpn-killswitch <= 0.4.0
Obsoletes:      python-proton-vpn-logger <= 0.2.1
BuildArch:      noarch
%python_subpackages

%description
This package contains a facade to the other Proton VPN components, exposing a uniform API for Proton VPN client.

%prep
%autosetup -p1 -n python-proton-vpn-api-core-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Failing tests, needs to be investigated
# See https://github.com/ProtonVPN/python-proton-vpn-api-core/issues/4
%pytest tests --ignore=tests/connection/test_vpnconfiguration.py --ignore=tests/connection/test_events.py --ignore=tests/connection/test_persistence.py --ignore=tests/connection/test_publisher.py --ignore=tests/connection/test_states.py --ignore=tests/connection/test_vpnconnection.py --ignore=tests/core/refresher/test_certificate_refresher.py --ignore=tests/core/refresher/test_client_config_refresher.py --ignore=tests/core/refresher/test_feature_flags_refresher.py --ignore=tests/core/refresher/test_server_list_refresher.py --ignore=tests/core/refresher/test_scheduler.py --ignore=tests/core/refresher/test_vpn_data_refresher.py --ignore=tests/core/test_connection.py --ignore=tests/core/test_settings.py --ignore=tests/core/test_usage.py

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/proton
%{python_sitelib}/proton_vpn_api_core-%{version}*-info

%changelog
* Mon Apr 14 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 0.42.4:
  * fix: [VPNLINUX-1191] swallow&re-schedule server refresh when we receive HTTP code 429
  * fix: [VPNLINUX-1191] swallow&re-schedule when we receive HTTP code 429 from refreshers
* Thu Mar 27 2025 Szymon Scholz <raspherdev@pm.me>
- Update to 0.42.3:
  * Expose method to get DNS IPs based on provided IP version
  * Always load feature flag cache/defaults
  * Add a breaks/conflicts clause for python3-proton-vpn-network-manager < 0.12.10
  * Fix Certificate Expired error when requesting certificate in pem format
  * Switch DisplayPortForwarding env var to Feature Flag
  * Added local agent to OpenVPN, minor bug fix
  * Added local agent to OpenVPN
  * Manage file containing forwarded port
  * Encrypt openvpn certificate private key
  * Notify connecting/disconnecting state early
  * Notify subscribers when state context changes
  * Fix sentry event username masking
  * Cleanup old feature flags
  * Update event context so that it passes a forwarded port
  * Ensure default settings use feature flags even after login the next time they are fetched
  * Switch default protocol to WireGuard if feature flag is present
  * Ensure no crash occurs if cache files are non-decodable
  * Set default expiration time for features flags to expired, so that they're fetched from the API and cached as soon as possible
  * Emit connection state update after state tasks are completed
  * Update how time is calculated in logging module
  * Drop Ubuntu 20.04 support
  * Added semgrep scanning to CI
  * Refactor custom DNS
  * Introduce custom DNS
  * Automatically generate the changelog files for debian and fedora
  * Switch to /vpn/v2 API
  * Use versioned API endpoints
  * Fix for certificate based authentication for openvpn, feature flag was out of date
  * Fix certificate expired regression
  * Enable certificate based authentication for openvpn
  * Improve logic on when to update location details
  * Use a 'before_send' callback in sentry to sanitize events in sentry
  * Update location object after successfully connecting to VPN server via local agent
* Tue Nov 12 2024 Alexandre Vicenzi <alexandre.vicenzi@suse.com>
- Enable sentry-sdk only in Tumbleweed
  * Not available in Leap/SLE
* Thu Oct 24 2024 Yunhe Guo <i@guoyunhe.me>
- Conflicts python-proton-vpn-connection
- Conflicts python-proton-vpn-killswitch
- Conflicts python-proton-vpn-logger
- Update to 0.35.5
  * Fix regression sending errors to sentry.
  * Fix to rpm package.spec, added accidentally removed Obsoletes statement.
  * Send all errors to sentry, but swallow api errors.
  * Merge logger package into this one.
  * Fix refregresion (logout user on 401 API error).
  * Catch and send LA errors to sentry.
  * Import refreshers from app.
  * Ensure there is a way to disable IPv6.
  * Change IPv6 default value and move out of the features dict.
  * Properly configure OpenVPN with IPv6 value.
  * Pass IPv6 value.
  * Put changes to fetching with timestamp (If-Modified-Since), behind a feature flag.
  * Fixes support for 'If-Modified-Since', expiration times.
  * Fixes support for 'If-Modified-Since' header in server list requests.
  * This adds support for 'If-Modified-Since' header in server list requests.
  * Make sure features cant be request after connection as well.
  * Expose property in VPNConnection to know if features can be applied on active connections.
  * Tier 0 level users can't control the features they have. So don't send any feature requests for them.
  * Fix crash after logout
  * Get rid of VPNConnectorWrapper.
  * Enable wireguard feature flag by default.
  * Handle UnicodeDecodeError when loading persisted VPN connection.
  * Update connection features via local agent if available.
  * Disconnect and notify the user when the maximum number of sessions is reached.
  * Handle ExpiredCertificate events.
  * Update default feature flags and update feature flags interface.
  * Update credentials in the background
  * Fix crash initializing VPN connector.
  * Update VPN credentials when an active VPN connection is found at startup.
  * Merge connection and kill switch packages into this one.
  * Improve testing to capture when default value is being passed.
  * Implement and expose feature flags.
  * Move local agent management into wireguard backend.
  * Send CPU architecture following semver's specs.
  * Switched over to async local agent api.
  * Attempt to use external local agent package, otherwise fallback to existent one.
  * Add the architecture in the appversion field for ProtonSSO.
  * Switch over to automatically generated changelogs for debian and rpm.
  * Fix sentry error sanitization crash.
  * Fix certificate duration regression.
  * Send wireguard certificate to server via local agent.
  * Increase certificate duration.
  * Refactor of Settings to ensure settings are only saved when they are changed.
  * Stop raising exceptions when getting wireguard certificate and it is expired.
* Wed May 22 2024 Alexandre Vicenzi <alexandre.vicenzi@suse.com>
- Update to 0.24.4
  * Filter OSError not just FileNotFound error in sentry.
  * Set the sentry user id based on a hash of /etc/machine-id
  * Fix deprecation warning when calculatin WireGuard certificate validity period.
  * Fix error saving cache file when parent directory does not exist
  * Only initialize sentry on first enable.
  * Forward SSL_CERT_FILE environment variable to sentry.
* Tue May  7 2024 Dirk Müller <dmueller@suse.com>
- update to 0.23.1:
  * Added missing pip dependencies.
  * Merged proton-vpn-api-session package into this one.
  * Pass requested features through to session login and two
    factor submit.
  * Provide method to update certificate.
  * Ensure that crash reporting state is preserved between
    restarts.
  * Explicitly state the sentry integrations we want. Dont
    include the ExceptHookIntegration
  * Change url for sentry, dont send server_name, use older
    sentry api
  * Add mechanism to send errors anonymously to sentry.
  * Return list of protocol plugins for a specific backend
    instead of returning a list of protocols names
  * Add WireGuard ports
* Thu Mar 21 2024 Yunhe Guo <i@guoyunhe.me>
- Update to version 0.21.0
  * Apply kill switch setting immediately
* Tue Mar 19 2024 Alexandre Vicenzi <alexandre.vicenzi@suse.com>
- Build for Leap
* Fri Feb  9 2024 Alexandre Vicenzi <alexandre.vicenzi@suse.com>
- Initial revision
